==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Image_Graph.pm <==
package WebGUI::i18n::English::Image_Graph;
use strict;

our $I18N = {
	'image width' => {
		message => q|Image width|,
		lastUpdated => 1131394070,
	},
	'image width description' => {
		message => q|The width of the complete image in pixels.|,
		lastUpdated => 1131394070,
	},
	'image height description' => {
		message => q|The height of the complete image in pixels.|,
		lastUpdated => 1131394070,
	},
	'image height' => {
		message => q|Image height|,
		lastUpdated => 1131394070,
	},
	'background color' => {
		message => q|Background color|,
		lastUpdated => 1131394070,
	},
	'background color description' => {
		message => q|The background (fill) color of the image.|,
		lastUpdated => 1131394070,
	},
	'palette' => {
		message => q|Palette|,
		lastUpdated => 1131394070,
	},
	'palette description' => {
		message => q|The palette that should be  used to draw the graph.|,
		lastUpdated => 1131394070,
	},
	'label offset' => {
		message => q|Label offset|,
		lastUpdated => 1131394070,
	},
	'label offset description' => {
		message => q|The distance between the labels and the graph
elements, like the axis or label sticks.|,
		lastUpdated => 1131394070,
	},
	'label font' => {
		message => q|Label font|,
		lastUpdated => 1131394070,
	},
	'label font description' => {
		message => q|The font that should be used to draw the labels.|,
		lastUpdated => 1131394070,
	},
	'label color' => {
		message => q|Label color|,
		lastUpdated => 1131394070,
	},
	'label color description' => {
		message => q|The color in which the labels should be drawn.|,
		lastUpdated => 1131394070,
	},
	'label fontsize' => {
		message => q|Font size|,
		lastUpdated => 1131394070,
	},
	'label fontsize description' => {
		message => q|The pointsize of the label font.|,
		lastUpdated => 1131394070,
	},
	'graph type' => {
		message => q|Graph type|,
		lastUpdated => 1131394070,
	},
	'graph type description' => {
		message => q|Use this option to select what kind of graph you
want to use.|,
		lastUpdated => 1131394070,
	},

	'no graphing plugins' => {
		message => q|No graphing plugins found|,
		lastUpdated => 1146451962,
	},

	'no graphing plugins in config' => {
		message => q|No graphing plugins are enabled in the config file.|,
		lastUpdated => 1163746146,
	},
};

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Image_Graph.pm <==
package WebGUI::i18n::English::Image_Graph;
use strict;

our $I18N = {
	'image width' => {
		message => q|Image width|,
		lastUpdated => 1131394070,
	},
	'image width description' => {
		message => q|The width of the complete image in pixels.|,
		lastUpdated => 1131394070,
	},
	'image height description' => {
		message => q|The height of the complete image in pixels.|,
		lastUpdated => 1131394070,
	},
	'image height' => {
		message => q|Image height|,
		lastUpdated => 1131394070,
	},
	'background color' => {
		message => q|Background color|,
		lastUpdated => 1131394070,
	},
	'background color description' => {
		message => q|The background (fill) color of the image.|,
		lastUpdated => 1131394070,
	},
	'palette' => {
		message => q|Palette|,
		lastUpdated => 1131394070,
	},
	'palette description' => {
		message => q|The palette that should be  used to draw the graph.|,
		lastUpdated => 1131394070,
	},
	'label offset' => {
		message => q|Label offset|,
		lastUpdated => 1131394070,
	},
	'label offset description' => {
		message => q|The distance between the labels and the graph
elements, like the axis or label sticks.|,
		lastUpdated => 1131394070,
	},
	'label font' => {
		message => q|Label font|,
		lastUpdated => 1131394070,
	},
	'label font description' => {
		message => q|The font that should be used to draw the labels.|,
		lastUpdated => 1131394070,
	},
	'label color' => {
		message => q|Label color|,
		lastUpdated => 1131394070,
	},
	'label color description' => {
		message => q|The color in which the labels should be drawn.|,
		lastUpdated => 1131394070,
	},
	'label fontsize' => {
		message => q|Font size|,
		lastUpdated => 1131394070,
	},
	'label fontsize description' => {
		message => q|The pointsize of the label font.|,
		lastUpdated => 1131394070,
	},
	'graph type' => {
		message => q|Graph type|,
		lastUpdated => 1131394070,
	},
	'graph type description' => {
		message => q|Use this option to select what kind of graph you
want to use.|,
		lastUpdated => 1131394070,
	},

	'no graphing plugins' => {
		message => q|No graphing plugins found|,
		lastUpdated => 1146451962,
	},

	'no graphing plugins in config' => {
		message => q|No graphing plugins are enabled in the config file.|,
		lastUpdated => 1163746146,
	},

	'Graphing' => {
		message => q|Graphing|,
		lastUpdated => 1251312907,
        context => q|Name of the tab that contains the form for graph configuration.|,
	},

};

1;
